v4.2 release. (#2587)
* Fix default cluster callback values to 1 to avoid profiler failure when these values are not set in command line. * v4.2 release.
This commit is contained in:
@@ -609,6 +609,8 @@ TEST(SM89_CuTe_Ada, CooperativeGemm_e5m2e5m2f32_MMA) {
|
||||
test_cooperative_gemm_col_major_layout<thread_block_size, MaxVecBits, TA, TB, TC>(shape_mnk, tiled_mma);
|
||||
}
|
||||
|
||||
#if (__CUDACC_VER_MAJOR__ > 12) || (__CUDACC_VER_MAJOR__ == 12 && __CUDACC_VER_MINOR__ >= 8)
|
||||
|
||||
TEST(SM89_CuTe_Ada, CooperativeGemm_e4m3e4m3f16_MMA) {
|
||||
using TA = cutlass::float_e4m3_t;
|
||||
using TB = cutlass::float_e4m3_t;
|
||||
@@ -680,3 +682,5 @@ TEST(SM89_CuTe_Ada, CooperativeGemm_e5m2e5m2f16_MMA) {
|
||||
|
||||
test_cooperative_gemm_col_major_layout<thread_block_size, MaxVecBits, TA, TB, TC>(shape_mnk, tiled_mma);
|
||||
}
|
||||
|
||||
#endif
|
||||
|
||||
@@ -44,7 +44,7 @@ __global__ void
|
||||
movm_test_device(uint16_t* g_in, uint16_t* g_out)
|
||||
{
|
||||
int tid = threadIdx.x;
|
||||
|
||||
|
||||
// load input gmem -> register
|
||||
uint32_t reg = reinterpret_cast<uint32_t*>(g_in)[tid];
|
||||
|
||||
@@ -128,7 +128,7 @@ TEST(SM75_CuTe_Turing, Movm)
|
||||
//
|
||||
// CuTe MOVM
|
||||
//
|
||||
|
||||
|
||||
{
|
||||
thrust::device_vector<uint16_t> d_out(count);
|
||||
|
||||
|
||||
Reference in New Issue
Block a user